@@ -8,7 +8,7 @@ fa4icons <- c(
   "barcode"
 )
 
-fa5icons <- c(
+fa6icons <- c(
   "chart-line",
   "socks",
   "bullhorn",
@@ -30,21 +30,21 @@ showIcons <- function(icons) {
     lapply(icons, function(name) {
       tags$tr(
         tags$td(style = "padding-right: 3em;", name),
-        tags$td(icon(name))
+        tags$td(shiny::icon(name))
       )
     })
   )
 }
 
 ui <- fluidPage(
-  tags$h2("Font Awesome 4 icons"),
-  p("The following icons are from the Font Awesome 4 set. They should display properly below."),
+  tags$h2("FontAwesome 4 Icons"),
+  p("The following icons are from FontAwesome 4. They should display properly below."),
   showIcons(fa4icons),
-  tags$h2("Font Awesome 5 icons"),
-  p("The following icons are from the Font Awesome 5 set. They should display properly below."),
-  showIcons(fa5icons),
-  tags$h2("Font Awesome 5 brand icons"),
-  p("The following icons are from the Font Awesome 5 brand set. They should display properly below."),
+  tags$h2("FontAwesome 6 Icons"),
+  p("The following icons are from FontAwesome 6. They should display properly below."),
+  showIcons(fa6icons),
+  tags$h2("FontAwesome 6 Brand icons"),
+  p("The following icons are from the FontAwesome 6 Brand set. They should display properly below."),
   showIcons(fabicons)
 )
 
